@@ -1,18 +1,10 @@
 import os
 import socket
-
-try:  # Python 2 # pragma: no cover
-    from urllib2 import Request
-except ImportError:  # Python 3 # pragma: no cover
-    from urllib.request import Request
+from urllib.request import Request
 
 _used_ports = set()
 
 
-here = os.path.dirname(os.path.abspath(__file__))
-assets = os.path.join(here, "assets")
-
-
 def find_unused_port():
     while True:
         service = socket.socket()
